[![Build Status](https://travis-ci.com/hasii2011/OrthogonalDrawing.svg?branch=master)](https://travis-ci.com/hasii2011/OrthogonalDrawing)

[![PyPI version](https://badge.fury.io/py/python3-albow.svg)](https://badge.fury.io/py/python3-albow)

This project is a port of Gregory Ewing's Albow project (https://www.pygame.org/project/338/4687) that is only
compatible with Python 2 and is unsupported since 2014.

Ported to Python 3 and extended by [Humberto A. Sanchez II](https://www.linkedin.com/in/hasii/)
Updated documentation at:  https://hasii2011.github.io


Install in your virtual environment with

pip3 install python3-albow
